@@ -18,7 +18,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import uuidutils
 
-from neutron_lbaas._i18n import _LI, _LE
 from neutron_lbaas.common.cert_manager import cert_manager
 from neutron_lbaas.common import exceptions
 
@@ -33,6 +32,11 @@ TLS_STORAGE_DEFAULT = os.environ.get(
 local_cert_manager_opts = [
     cfg.StrOpt('storage_path',
                default=TLS_STORAGE_DEFAULT,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help='Absolute path to the certificate storage directory. '
                     'Defaults to env[OS_LBAAS_TLS_STORAGE].')
 ]
@@ -85,9 +89,7 @@ class CertManager(cert_manager.CertManager):
         cert_ref = uuidutils.generate_uuid()
         filename_base = os.path.join(CONF.certificates.storage_path, cert_ref)
 
-        LOG.info(_LI(
-            "Storing certificate data on the local filesystem."
-        ))
+        LOG.info("Storing certificate data on the local filesystem.")
         try:
             filename_certificate = "{0}.crt".format(filename_base)
             with open(filename_certificate, 'w') as cert_file:
@@ -107,7 +109,7 @@ class CertManager(cert_manager.CertManager):
                 with open(filename_pkp, 'w') as pass_file:
                     pass_file.write(private_key_passphrase)
         except IOError as ioe:
-            LOG.error(_LE("Failed to store certificate."))
+            LOG.error("Failed to store certificate.")
             raise exceptions.CertificateStorageException(message=ioe.message)
 
         return cert_ref
@@ -123,7 +125,7 @@ class CertManager(cert_manager.CertManager):
                  representation of the certificate data
         :raises CertificateStorageException: if certificate retrieval fails
         """
-        LOG.info(_LI(
+        LOG.info((
             "Loading certificate {0} from the local filesystem."
         ).format(cert_ref))
 
@@ -140,7 +142,7 @@ class CertManager(cert_manager.CertManager):
             with open(filename_certificate, 'r') as cert_file:
                 cert_data['certificate'] = cert_file.read()
         except IOError:
-            LOG.error(_LE(
+            LOG.error((
                 "Failed to read certificate for {0}."
             ).format(cert_ref))
             raise exceptions.CertificateStorageException(
@@ -150,7 +152,7 @@ class CertManager(cert_manager.CertManager):
             with open(filename_private_key, 'r') as key_file:
                 cert_data['private_key'] = key_file.read()
         except IOError:
-            LOG.error(_LE(
+            LOG.error((
                 "Failed to read private key for {0}."
             ).format(cert_ref))
             raise exceptions.CertificateStorageException(
@@ -180,7 +182,7 @@ class CertManager(cert_manager.CertManager):
 
         :raises CertificateStorageException: if certificate deletion fails
         """
-        LOG.info(_LI(
+        LOG.info((
             "Deleting certificate {0} from the local filesystem."
         ).format(cert_ref))
 
@@ -197,7 +199,7 @@ class CertManager(cert_manager.CertManager):
             os.remove(filename_intermediates)
             os.remove(filename_pkp)
         except IOError as ioe:
-            LOG.error(_LE(
+            LOG.error((
                 "Failed to delete certificate {0}."
             ).format(cert_ref))
             raise exceptions.CertificateStorageException(message=ioe.message)
