@@ -12,11 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron.common import rpc as n_rpc
 from neutron.db import agents_db
-from neutron.db import common_db_mixin
 from neutron.services import provider_configuration as provconf
 from neutron_lib import exceptions as n_exc
+from neutron_lib import rpc as n_rpc
 from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_utils import importutils
@@ -163,8 +162,7 @@ class LoadBalancerAgentApi(object):
 
 
 class LoadBalancerManager(driver_base.BaseLoadBalancerManager,
-                          agent_scheduler_v2.LbaasAgentSchedulerDbMixin,
-                          common_db_mixin.CommonDbMixin):
+                          agent_scheduler_v2.LbaasAgentSchedulerDbMixin):
     def __init__(self, driver):
         super(LoadBalancerManager, self).__init__(driver)
         self.db = ldbv2.LoadBalancerPluginDbv2()
@@ -403,7 +401,7 @@ class AgentDriverBase(driver_base.LoadBalancerBaseDriver):
         if hasattr(self.plugin, 'agent_callbacks'):
             return
 
-        self.conn = n_rpc.create_connection()
+        self.conn = n_rpc.Connection()
         self.conn.create_consumer(lb_const.LOADBALANCER_PLUGINV2,
                                   self.agent_endpoints,
                                   fanout=False)
